@@ -4,10 +4,10 @@
 #' @param p Character;
 #'
 #' Pollutants: "CO", "HC", "NMHC", "CH4", "NOx", "CO2","RCHO", "ETOH",
-#' "PM", "N2O", "KML", "FC", "NO2d", "NOd", "gD/KWH", "gCO2/KWH", "RCHO",
+#' "PM", "N2O", "KML", "FC", "NO2", "NO", "gD/KWH", "gCO2/KWH", "RCHO",
 #' "CO_0km", "HC_0km", "NMHC_0km", "NOx_0km", "NO2_0km" ,"NO_0km",
-#' "RCHO_0km" and "ETOH_0km",
-#' (g/km).  Evaporative emissions at average temperature ranges:
+#' "RCHO_0km" and "ETOH_0km", "FS" (fuel sales) (g/km).
+#' Evaporative emissions at average temperature ranges:
 #' "D_20_35", "S_20_35", "R_20_35", "D_10_25", "S_10_25", "R_10_25", "D_0_15",
 #' "S_0_15" and "R_0_15" where D means diurnal (g/day), S hot/warm soak (g/trip)
 #' and R hot/warm running losses (g/trip).
@@ -23,6 +23,7 @@
 #' @param year Numeric; Filter the emission factor to start from a specific base year.
 #' If project is 'constant' values above 2017 and below 1980 will be repeated
 #' @param agemax Integer; age of oldest vehicles for that category
+#' @param sppm Numeric, sulfur (sulphur) in ppm in fuel.
 #' @param full Logical; To return a data.frame instead or a vector adding
 #' Age, Year, Brazilian emissions standards and its euro equivalents.
 #' @param project haracter showing the method for projecting emission factors in
@@ -84,8 +85,29 @@
 #' "M_G_150_500", "M_G_500", "M_FG_150", "M_FG_150_500", "M_FG_500",
 #' "M_FE_150", "M_FE_150_500","M_FE_500",
 #'
+#' If pollutant is "SO2", it needs sppm. It is designed when veh has length 1, if it has length 2 or more,
+#' it will show a warning
+#'
+#' \strong{Emission factor for vehicles older than the reported by CETESB were filled as the moving average of 2:}
+#'
+#' \itemize{
+#' \item Range EF from PC and LCV otto: 2018 - 1982. EF for 1981 and older as movign average.
+#' \item Range LCV diesel : 2018 - 2006. EF for 2005 and older as movign average.
+#' \item Range Trucks and Buse: 2018 - 1998. EF for 1997 and older as movign average.
+#' \item Range MC Gasoline: 2018 - 2003.  EF for 2002 and older as movign average.
+#' \item Range MC Flex 150-500cc and >500cc: 2018 - 2012.  EF for 2011 and older as movign average.
+#'}
 #' @references Emissoes Veiculares no Estado de Sao Paulo 2016. Technical Report.
 #' url: https://cetesb.sp.gov.br/veicular/relatorios-e-publicacoes/.
+#'
+#' @note Currently, 2020, there are not any sistem for recovery of fuel vapors in Brazil. Hence,
+#' the FS takes into account the vapour that comes from the fuel tank inside the car and
+#' released into the atmosphere when injecting new fuel. There are discussions about
+#' incrementing implementing stage I and II and/or ORVR thesedays. The ef FS is calculated
+#' by transforming g FC/km into  (L/KM)*g/L with g/L 1.14 fgor gasoline and 0.37
+#' for ethanol (CETESB, 2016). The density considered is 0.75425 for gasoline and
+#' 0.809 for ethanol (t/m^3)
+#'
 #' @export
 #' @examples \dontrun{
 #' a <- ef_cetesb("CO", "PC_G")
@@ -96,8 +118,17 @@
 #' ef_cetesb(p = "CO", veh = "PC_G", year = 2030, agemax = 40)
 #' ef_cetesb(p = "CO", veh = "TRUCKS_L_D", year = 2018)
 #' ef_cetesb(p = "CO", veh = "SLT", year = 2018) #  olds names
+#' ef_cetesb(p = "SO2", veh = "PC_G", year = 2030, agemax = 40, sppm = 300)
+#' ef_cetesb(p = "SO2", veh = "PC_FE", year = 2030, agemax = 40, sppm = 300)
 #' }
-ef_cetesb <- function(p, veh, year = 2017, agemax = 40, full = FALSE, project = "constant", verbose = FALSE){
+ef_cetesb <- function(p,
+                      veh,
+                      year = 2017,
+                      agemax = 40,
+                      sppm,
+                      full = FALSE,
+                      project = "constant",
+                      verbose = FALSE){
   ef <- sysdata$cetesb
   ef[is.na(ef)] <- 0
 
@@ -129,91 +160,115 @@ ef_cetesb <- function(p, veh, year = 2017, agemax = 40, full = FALSE, project =
                   "M_FE_500" = "MC_500_FE")
     message(veh)
   }
-      year1 <- ef$Year[1]
+  year1 <- ef$Year[1]
 
-    p <- gsub(pattern = "d", replacement = "", x = p) #not break old code
+  p <- gsub(pattern = "d", replacement = "", x = p) #not break old code
 
-    if(year < 1956) stop("Choose a newer year")
-    # Selecting
-    ef <- ef[ef$Year <= year, ]
+  s0 <- c("PC_E", "PC_FE", "LCV_E", "LCV_FE",
+          "MC_150_FE", "MC_150_500_FE", "MC_500_FE")
 
-    evapd <- c("D_20_35","D_10_25","D_0_15")
-    evap <- c("S_20_35", "R_20_35", "S_10_25", "R_10_25", "S_0_15", "R_0_15")
-    pols <- as.character(unique(ef$Pollutant))
-    if(!p %in% pols){
-      stop(cat("Please, choose one of the following pollutants:\n", pols, "\n"))
+  if(p == "SO2"){
+    if(missing(sppm)) stop("if p is 'SO2', sppm must be present")
+    if(length(veh) != length(sppm)) {
+      stop("sppm must has the same length as veh")
     }
-    if(p %in% evapd){
-      if(verbose) message("Units: [g/day]\n")
-    }
-    if(p %in% evap){
-      if(verbose) message("Units: [g/trip]\n")
-    }
-    nveh <- names(ef)[12:ncol(ef)]
-    if(any(!veh %in% nveh)){
-      stop(cat("Please, choose on of the following categories:\n", nveh, "\n"))
-    }
-    if(full) {
-      if(p %in% c(evapd, evap)){
-        df <- cbind(ef[ef$Pollutant == p, 1:11],
-                    ef[ef$Pollutant == p, veh])
-        names(df)[ncol(df)] <- p
+  }
 
-      } else {
-        df <- cbind(ef[ef$Pollutant == p, 1:11],
-                    EmissionFactors(ef[ef$Pollutant == p, veh]))
-        names(df)[ncol(df)] <- p
+  if(year < 1956) stop("Choose a newer year")
+  # Selecting
+  ef <- ef[ef$Year <= year, ]
 
-      }
-    } else{
-      if(p %in% c(evapd, evap)){
-        df <- ef[ef$Pollutant == p, veh]
-      } else {
-        df <- vein::EmissionFactors(ef[ef$Pollutant == p, veh])
-      }
+  evapd <- c("D_20_35","D_10_25","D_0_15")
+  evap <- c("S_20_35", "R_20_35", "S_10_25", "R_10_25", "S_0_15", "R_0_15")
+  pols <- as.character(unique(ef$Pollutant))
 
-    }
-    if(is.data.frame(df)){
-      # project future EF
-      if(project == "constant"){
-        if(year > year1){
-          dif <- year - year1
+  if(!p %in% c(pols, "SO2")){
+    stop(cat("Please, choose one of the following pollutants:\n", pols, "\n"))
+  }
 
-          eff <- do.call("rbind",(lapply(1:dif, function(i){
-            df[1, ]
-          })))
-          edff <- rbind(eff, df[1:(agemax - dif), ])
-        }
-      }
+  if(p %in% evapd){
+    if(verbose) message("Units: [g/day]\n")
+  }
+  if(p %in% evap){
+    if(verbose) message("Units: [g/trip]\n")
+  }
+  nveh <- names(ef)[12:ncol(ef)]
+  if(any(!veh %in% nveh)){
+    stop(cat("Please, choose on of the following categories:\n", nveh, "\n"))
+  }
 
-      #Filling older ef
-      if(!missing(agemax)){
-        if(nrow(df) < agemax){
-          dif <- agemax - nrow(df)
-          df[nrow(df):(nrow(df)+dif), ] <- df[nrow(df), ]
-        }
-        df <-  df[1:agemax, ]
-      }
+
+
+  pol <- p
+  k <- ifelse(p == "SO2", sppm*2*1e-06, 1)
+  p <- ifelse(p == "SO2", "FC", p)
+
+  if(full) {
+    if(p %in% c(evapd, evap)){
+      df <- cbind(ef[ef$Pollutant == p, 1:11],
+                  ef[ef$Pollutant == p, veh])
+      names(df)[ncol(df)] <- p
 
     } else {
-      # project future EF
-      if(project == "constant"){
-        if(year > year1){
-          dif <- year - year1
-          eff <- rep(df[1], dif)
-          df <- c(eff, df[1:(agemax - dif)])
-        }
+      if(pol == "SO2" & length(veh) == 1){
+        if(veh %in% s0) k = 0
       }
-
-      #Filling older ef
-      if(!missing(agemax)){
-        if(length(df) < agemax){
-          dif <- agemax - length(df)
-          df[length(df):(length(df)+dif)] <- df[length(df)]
-        }
-        df <-  df[1:agemax]
-      }
-
+      df <- cbind(ef[ef$Pollutant == p, 1:11],
+                  EmissionFactors(ef[ef$Pollutant == p, veh]*k)  )
+      names(df)[ncol(df)] <- p
     }
-    return(df)
+  } else {
+    if(p %in% c(evapd, evap)){
+      df <- ef[ef$Pollutant == p, veh]
+    } else {
+      if(pol == "SO2" & length(veh) == 1){
+        if(veh %in% s0) k = 0
+      }
+      df <- vein::EmissionFactors(ef[ef$Pollutant == p, veh]*k)
+    }
+
+  }
+  if(is.data.frame(df)){
+    # project future EF
+    if(project == "constant"){
+      if(year > year1){
+        dif <- year - year1
+
+        eff <- do.call("rbind",(lapply(1:dif, function(i){
+          df[1, ]
+        })))
+        edff <- rbind(eff, df[1:(agemax - dif), ])
+      }
+    }
+
+    #Filling older ef
+    if(!missing(agemax)){
+      if(nrow(df) < agemax){
+        dif <- agemax - nrow(df)
+        df[nrow(df):(nrow(df)+dif), ] <- df[nrow(df), ]
+      }
+      df <-  df[1:agemax, ]
+    }
+
+  } else {
+    # project future EF
+    if(project == "constant"){
+      if(year > year1){
+        dif <- year - year1
+        eff <- rep(df[1], dif)
+        df <- c(eff, df[1:(agemax - dif)])
+      }
+    }
+
+    #Filling older ef
+    if(!missing(agemax)){
+      if(length(df) < agemax){
+        dif <- agemax - length(df)
+        df[length(df):(length(df)+dif)] <- df[length(df)]
+      }
+      df <-  df[1:agemax]
+    }
+
+  }
+  return(df)
 }
